pub struct LongLivedToken { /* private fields */ }Expand description
A token manager for long lived tokens (such as service account tokens or personal access tokens). This will simply configure the request to always return the provided token
Implementations