StandaloneWrite

Struct StandaloneWrite 

pub struct StandaloneWrite { /* private fields */ }
A type that can write all bindle data to the configured location as a standalone bindle

Implementations

Source

impl StandaloneWrite

pub async fn new<P, I>(base_path: P, bindle_id: I) -> Result<StandaloneWrite>
where P: AsRef<Path>, I: TryInto<Id>, I::Error: Into<ClientError>,

Returns a new StandaloneWrite that can write all components of a bindle as a standalone bindle using the given base path and bindle ID

use bindle::standalone::StandaloneWrite;

StandaloneWrite::new("/foo/bar", "example.com/baz/1.0.0").await.unwrap();

In the above example, the StandaloneWrite will be configured to write all the bindle data into the /foo/bar/187e908f466500c76c13953c3191fafa869c277e2689f451e92d75cda32452df directory

pub fn path(&self) -> &Path

Returns a reference to the output directory for this standalone bindle

pub async fn tarball(self, output_dir: impl AsRef<Path>) -> Result<()>

Creates a tarball, consuming the StandaloneWrite and outputting the tarball at the given path

pub async fn write<T: AsyncRead + Unpin + Send + Sync>( &self, inv: Invoice, parcels: HashMap<String, T>, ) -> Result<()>

Writes the given invoice and HashMap of parcels (as readers). The key of the HashMap should be the SHA of the parcel

The HashMap key should be the sha256 of the data, and the value should be the parcel content.

pub async fn write_stream<E, T>( &self, inv: Invoice, parcels: HashMap<String, T>, ) -> Result<()>
where E: Error, T: Stream<Item = Result<Bytes, E>> + Unpin,

Writes the given invoice and collection of parcel streams