pub enum VerificationStrategy {
CreativeIntegrity,
AuthoritativeIntegrity,
GreedyVerification,
ExhaustiveVerification,
MultipleAttestation(Vec<SignatureRole>),
MultipleAttestationGreedy(Vec<SignatureRole>),
}Expand description
This enumerates the verifications strategies described in the signing spec.
Variants
CreativeIntegrity
CreativeIntegrity verifies that (a) the key that signs as Creator is a known key, and that the signature is valid.
AuthoritativeIntegrity
AuthoritativeIntegrity verifies that at least one of the Creator or Approver keys is known and the signature is valid.
GreedyVerification
Verify that the Creator key is known and that all signatures are valid.
This is subject to a DOS attack if a signer can generate intentionally bad signatures.
ExhaustiveVerification
Verify that every key on the invoice is known, and that every signature is valid.
MultipleAttestation(Vec<SignatureRole>)
Verifies that all signatures of the given roles are valid and signed by known keys.
MultipleAttestationGreedy(Vec<SignatureRole>)
Verifies that all signatures of the given roles are valid and signed by known keys. Will also validate unknown signers similar to GreedyVerification
Unknown signers will also be validated. Be aware that doing so may make the validation subject to a special form of DOS attack in which someone can generate a known-bad signature.
Implementations
Sourceimpl VerificationStrategy
A strategy for verifying an invoice.
impl VerificationStrategy
A strategy for verifying an invoice.
Sourcepub fn verify<I>(
&self,
invoice: I,
keyring: &KeyRing,
) -> Result<VerifiedInvoice<I>, SignatureError>
pub fn verify<I>( &self, invoice: I, keyring: &KeyRing, ) -> Result<VerifiedInvoice<I>, SignatureError>
Verify that every signature on this invoice is correct.
The verification strategy will determine how this verification is performed.
Depending on the selected strategy, the [[signature]] blocks will be evaluated
for the following:
- Is the key in the keyring?
- Can the signature be verified?
Note that the purpose of the keyring is to ensure that we know about the entity that claims to have signed the invoice.
If no signatures are on the invoice, this will succeed.
A strategy will determine success or failure based on whether the signature is verified, whether the keys are known, whether the requisite number/roles are satisfied, and so on.