pub async fn setup() -> (FileProvider<StrictEngine>, StrictEngine, MockKeyStore)Expand description
Returns a file Provider implementation configured with a temporary directory, strict Search
implementation, and a mock key store for use in testing API endpoints